var _a, _b;
import mockFetchOn from './core';
// Export core package
export * from './core';
export { mockFetchOn };
// Lib compatibility checks.
const swSupported = typeof window !== 'undefined' && !!((_a = window === null || window === void 0 ? void 0 : window.navigator) === null || _a === void 0 ? void 0 : _a.serviceWorker);
const isInNode = typeof process !== 'undefined' && ((_b = process === null || process === void 0 ? void 0 : process.release) === null || _b === void 0 ? void 0 : _b.name) === 'node';
// Lib clients. Initialize when needed.
let channel;
let mswInterceptors;
// Lib controllers.
let libIsActive;
let libActivate;
let libRestore;
// Mock globalThis and activate by default.
const fetchMock = mockFetchOn(globalThis);
fetchMock.activate();
const onfetch = Object.assign(
// Use a copy to avoid overwriting the fetchMock props in runtime.
fetchMock.bind(fetchMock), fetchMock, {
    async useServiceWorker() {
        if (!channel) {
            if (!swSupported) {
                throw new Error('Environment not compatible with service worker mode');
            }
            const Channel = (await import('./lib/SW/Channel')).default;
            channel = new Channel(window.navigator.serviceWorker);
        }
        await this.adopt(channel, channel);
        fetchMock.config({
            bypassRedirect: true,
        });
    },
    async useMSWInterceptors() {
        if (!mswInterceptors) {
            if (!isInNode) {
                throw new Error('Environment not compatible with msw interceptor mode');
            }
            const MSWInterceptors = (await import('./lib/MSWInterceptors')).default;
            mswInterceptors = new MSWInterceptors();
        }
        await this.adopt(mswInterceptors, mswInterceptors);
        fetchMock.config({
            bypassRedirect: true,
        });
    },
    async useAutoAdvanced() {
        if (swSupported) {
            await this.useServiceWorker();
        }
        else if (isInNode) {
            await this.useMSWInterceptors();
        }
        else {
            throw new Error('Environment not compatible with any advanced mode');
        }
    },
    async useDefault() {
        await this.adopt(globalThis);
        fetchMock.config({
            bypassRedirect: false,
        });
    },
    isActive() {
        return libIsActive ? libIsActive() : fetchMock.isActive.call(fetchMock);
    },
    async activate() {
        await (libActivate === null || libActivate === void 0 ? void 0 : libActivate());
        fetchMock.activate();
    },
    async restore() {
        fetchMock.restore();
        await (libRestore === null || libRestore === void 0 ? void 0 : libRestore());
    },
    async adopt(context, controllers = {}) {
        const { isActive, activate, restore } = controllers;
        const wasActive = this.isActive();
        await (libRestore === null || libRestore === void 0 ? void 0 : libRestore());
        libIsActive = isActive;
        libActivate = activate;
        libRestore = restore;
        fetchMock.adopt(context);
        if (wasActive)
            await (activate === null || activate === void 0 ? void 0 : activate());
    },
});
export default onfetch;
