import { FulfillList, StatusMessage, RequestMessage, ResponseMessage } from './Message';
/**
 * A fetch receiver
 * - For received requests, message to service worker.
 * - For messaged requests, send to the receiver. <- Intercept here.
 */
export default class Channel {
    port?: MessagePort;
    fulfillList?: FulfillList;
    private beActive;
    constructor(workerContainer: ServiceWorkerContainer);
    private registerController;
    /**
     * For received requests, message to the service worker.
     */
    fetch: typeof fetch;
    onMessage: (event: MessageEvent) => void;
    /**
     * For messaged requests, send to the receiver.
     */
    onRequestMessage: (event: MessageEvent<RequestMessage>) => Promise<void>;
    /**
     * For messaged responses, treat as a previous received request's response.
     */
    onResponseMessage: (event: MessageEvent<ResponseMessage>) => void;
    statusResolve: (() => void) | null;
    onStatusMessage: (event: MessageEvent<StatusMessage>) => void;
    isActive: () => boolean;
    switchToStatus(status: 'on' | 'off'): Promise<void>;
    /**
     * Start receiving worker messages.
     */
    activate: () => Promise<void>;
    /**
     * Stop receiving worker messages.
     */
    restore: () => Promise<void>;
}
//# sourceMappingURL=Channel.d.ts.map