/// <reference types="serviceworker" />
import { FulfillList, StatusMessage, RequestMessage, ResponseMessage } from './Message';
/**
 * A fetch forwarder
 * - For captured requests, message back to client.
 * - For messaged requests, message back the real response.
 */
export default class Worker {
    scope: ServiceWorkerGlobalScope;
    portMap: Map<string, MessagePort>;
    fulfillListMap: Map<MessagePort, FulfillList>;
    constructor(scope: ServiceWorkerGlobalScope);
    /**
     * For captured requests, message back to the client.
     */
    onFetch: (event: FetchEvent) => void;
    onMessage: (event: MessageEvent) => void;
    /**
     * For messaged requests, respond with real responses.
     */
    onRequestMessage: (event: MessageEvent<RequestMessage>) => Promise<void>;
    /**
     * For messaged responses, treat as a previous captured request's response.
     */
    onResponseMessage: (event: MessageEvent<ResponseMessage>) => void;
    statusResolveMap: Map<MessagePort, (() => void) | null>;
    onStatusMessage: (event: MessageEvent<StatusMessage>) => void;
    hasActive(): boolean;
    switchToStatus(status: 'on' | 'off'): Promise<void>;
    /**
     * Start capturing requests and receiving messages.
     */
    activate(): Promise<void>;
    /**
     * Stop capturing requests and receiving messages.
     */
    restore(): Promise<void>;
}
//# sourceMappingURL=Worker.d.ts.map